/*
File:   EEPROM.ASM

Copyright 1998, 1999 Larry Barello

Author: Larry Barello
        lbarello@accessone.com

You are allowed to use this file for personal use only.

You may use, embed, modify or distribute the contents
of this file in any way you see fit as long as you 
include this copyright notice in the resulting file.

Any commercial or industrial use including publishing
or distributing in any form requires the written 
authorization of the copyright holder(s).

No guarantees are made about fitness, functionality, 
correctness or performance of this file.  The file is 
supplied on a "AS IS" basis, with no responsibility 
assumed by the author(s) for bug fixes, support, or 
damages of any sort arising from the use of this file. 

Contact the author with problem reports or fixes, 
feature requests or additions and questions.  They 
are welcomed and will be incorporated as time and 
energy permits.

*/
        MODULE  SUMOEEPROM
        
        RSEG    EEPROM

        EXTERN  TICKRATE

        PUBLIC  TargetTable TargetTableEnd TargetTableEntry
        PUBLIC  Servo_Latency Spin_180_Degrees Spin_135_Degrees Spin_90_Degrees Reverse_Duration
        PUBLIC  TargetFar TargetNear NoTarget
        PUBLIC  TTCenter TTEnd

#define         EXPERT_S200_SERVO       ; Brand of uServo we are using        

TTCenter:       DW      DeadAhead       ; To allow dynamic tables w/o code changes
TTEnd:          DW      TargetTableEnd
Servo_Latency:  DB      4               ; 1/50 second
;
; Boundry Behavior
;
Spin_90_Degrees:
                DB      high(TICKRATE*3/8)
                DB      low (TICKRATE*3/8)
Spin_180_Degrees:
                DB      high(TICKRATE*2/3)
                DB      low (TICKRATE*2/3)
Reverse_Duration:
                DB      high(TICKRATE/4)
                DB      low (TICKRATE/4)
Spin_135_Degrees:
                DB      high(TICKRATE/2)
                DB      low (TICKRATE/2)
;
; Min-Max for proximity
;
NoTarget:       DB      0x45            ; About 22"
TargetFar:      DB      0x5F            ; About 9"
TargetNear:     DB      0xAE            ; About 2"
;
; Table of servo positions and drive values for targeting, this is last so the
; table can be grown or shrunk without reloading code.
;
Sec     Define  TICKRATE

#ifdef  HITECH_HS422_SERVO
;                       Servo Left  Right           Turn
TargetTable:    ;        Pos  ---Drive -- -------- Duration ----------
                DB      0xC0, 0x80, 0x7f, high(Sec*4/16), low(Sec*4/16)     ; Right
                DB      0xB0, 0x80, 0x7F, high(Sec*3/16), low(Sec*3/16)     ; Mid-Right
                DB      0xA0, 0x80, 0x7F, high(Sec*2/16), low(Sec*2/16)     ; Mid-Left
                DB      0x90, 0x80, 0x7F, high(Sec*1/16), low(Sec*1/16)     ; Mid-Left
DeadAhead:      DB      0x80, 0x7F, 0x7F, high(Sec*0/16), low(Sec*0/16)                       ; Dead Ahead
                DB      0x70, 0x7F, 0x80, high(Sec*1/16), low(Sec*1/16)     ; Mid-Left
                DB      0x60, 0x7F, 0x80, high(Sec*2/16), low(Sec*2/16)     ; Mid-Left
                DB      0x50, 0x7F, 0x80, high(Sec*3/16), low(Sec*3/16)     ; Mid-Left
TargetTableEnd: DB      0x40, 0x7F, 0x80, high(Sec*4/16), low(Sec*4/16)     ; Left
#endif

#ifdef  EXPERT_S200_SERVO
;                       Servo Left  Right           Turn
TargetTable:    ;        Pos  ---Drive -- -------- Duration ----------
                DB      0xE8, 0x80, 0x7f, high(Sec*4/16), low(Sec*4/16)     ; Right
                DB      0xCF, 0x80, 0x7F, high(Sec*3/16), low(Sec*3/16)     ; Mid-Right
                DB      0xB6, 0x80, 0x7F, high(Sec*2/16), low(Sec*2/16)     ; Mid-Left
                DB      0x9D, 0x80, 0x7F, high(Sec*1/16), low(Sec*1/16)     ; Mid-Left
DeadAhead:      DB      0x84, 0x7F, 0x7F, high(Sec*0/16), low(Sec*0/16)                       ; Dead Ahead
                DB      0x71, 0x7F, 0x80, high(Sec*1/16), low(Sec*1/16)     ; Mid-Left
                DB      0x5E, 0x7F, 0x80, high(Sec*2/16), low(Sec*2/16)     ; Mid-Left
                DB      0x4B, 0x7F, 0x80, high(Sec*3/16), low(Sec*3/16)     ; Mid-Left
TargetTableEnd: DB      0x38, 0x7F, 0x80, high(Sec*4/16), low(Sec*4/16)     ; Left
#endif

TargetTableEntry        = 5     ; Size of each entry (fixed)

        END
